@@ -62,10 +62,10 @@ pub fn solve(
         return Err("Empty input".to_string());
     } else if !input_string.is_ascii() {
         return Err("Non-ASCII input".to_string());
-    } else if !matches!(day, 0..=25) {
-        return Err(format!("Invalid day: {} - must be 1-25", day));
+    } else if !matches!(day, 1..=25) {
+        return Err(format!("Invalid day {} - must be 1-25", day));
     } else if !matches!(part, 1 | 2) {
-        return Err(format!("Invalid part: {} - must be 1-2", part));
+        return Err(format!("Invalid part {} - must be 1-2", part));
     }
 
     let mut input = Input {
@@ -236,12 +236,10 @@ pub fn solve(
         (2019, 21, 2) => to_stringer(year2019::day21::part2, input_string),
         (2019, 22, 1) => to_stringer(year2019::day22::part1, input_string),
         (2019, 22, 2) => to_stringer(year2019::day22::part2, input_string),
-        (2019, 23, 1) => to_stringer(year2019::day23::part1, input_string),
-        (2019, 23, 2) => to_stringer(year2019::day23::part2, input_string),
+        (2019, 23, _) => to_stringer_input(year2019::day23::solve, &mut input),
         (2019, 24, 1) => to_stringer(year2019::day24::part1, input_string),
         (2019, 24, 2) => to_stringer(year2019::day24::part2, input_string),
-        (2019, 25, 1) => to_stringer(year2019::day25::part1, input_string),
-        (2019, 25, 2) => to_stringer(year2019::day25::part2, input_string),
+        (2019, 25, _) => to_stringer_input(year2019::day25::solve, &mut input),
         (2020, 1, _) => to_stringer_input(year2020::day01::solve, &mut input),
         (2020, 2, _) => to_stringer_input(year2020::day02::solve, &mut input),
         (2020, 3, _) => to_stringer_input(year2020::day03::solve, &mut input),
